@@ -11,15 +11,15 @@ int queue_open(struct queue *self);
 
 void queue_close(struct queue *self);
 
-int queue_bind(struct queue *self);
+int queue_bind(struct queue *self, int af_family);
 
-int queue_unbind(struct queue *self);
+int queue_unbind(struct queue *self, int af_family);
 
 int queue_set_queue_maxlen(struct queue *self, int maxlen);
 
 int queue_create_queue(struct queue *self, int queue_num);
 
-int queue_fast_open(struct queue *self, int queue_num);
+int queue_fast_open(struct queue *self, int queue_num, int af_family);
 
 int queue_try_run(struct queue *self);
 
